<html>
<body background="UNR_Seal.gif">
<center>
<img src="UNR_Logo.gif">
<p> &nbsp; </p>
<table  border = 0>
<tr><!--<td><a href = "login.php">LOGIN HOME PAGE</a></td><td></td>/-->
    <td><a href = "display.php">MANAGEMENT STAFF PAGE</a></td><td>  |  </td>	
    <!--<td> | </td>//-->
    <!--<td><img src = "unr.gif"> //-->
    <!--<td><a href = "newUser.php">ADD NEW USER</a></td><td> | </td>
    <td><a href = "updateU.php">DELETE/UPDATE/VIEW USER</a></td><td> | </td>//-->
    <td><a href = "logout.php">LOGOUT</a></td>
</table>
<hr>
</center>
</body>
</html>
