<?
/*********************************************************
* Filename: logout.php
* Purpose: Enables user to logout of system
* Version information
* Date: November 5, 2001
* Copyright notice
***********************************************************/

   session_start();
   session_unset();
   session_destroy();
   header("Location: login.php");
?>
