<?
/*********************************************************
* Filename: page.php
* Purpose: Informs user that login is valid
* Version information
* Date: November 5, 2001
* Copyright notice
***********************************************************/

//** Do not allow user to visit page by hitting back button */
session_cache_limiter('nocache');
 session_start();
 if($validLogin != 1){
	header("Location: logout.php");
 }

if($userType == 's')
	header("Location: student.php");
else if($userType == 'a')
	header("Location: applicant.php");
else if($userType == 'm')
	header("Location: display.php");
else if ($userType == 'f')
	header("Location: faculty.php");
else if ($userType == 'v')
	header("Location: faculty.php");
else if ($userType == 'c')
	header("Location: committee.php");
else if ($userType == 'd')
	header("Location: director.php");
else{
	echo"GO AWAY YOU HAVE NO HOME HERE";
}

?>
<html>
<body>
<p><? echo"$username "; ?> is connected</p>
<p><? echo"$firstName  $lastName"; ?> is <? echo"$username"; ?>'s real name</p>
<!--<p><a href="student.php">View Info</a></p> //-->
<p><a href="logout.php">Log Out</a></p>

</body>
</html>
