<?
/*****************************************************************
* filename: committe.php
* Purpose: for committee member to view students/applicants
*          infomation, to send FAQ to assistant, and to
*          evaluate an applicant
* Version information 1.0
* Date: December 4,2001
******************************************************************/

session_start();

if($userType!='c')
 header("Location: logout.php");

?>


<HTML>
<HEAD>
<TITLE> GPA for Committee </TITLE>
</HEAD>


<BODY BACKGROUND="UNR_Seal.gif">
<CENTER><img src="UNR_Logo.gif">  </CENTER>
<CENTER>
<TABLE BORDER=2 CELLSPACING=5 CELLPADDING=5 WIDTH="60%" HEIGHT="40">
<TR><STRONG><B>GPA for Committee</STRONG></B><BR><BR><BR>

<FORM ACTION="committeeView.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Viewing Students' Info"></CENTER></TD></FORM>

<FORM ACTION="committeeReport.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Reporting Students' Grades"></CENTER></TD></FORM>

<FORM ACTION="committeeFAQ.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Sending an FAQ"></CENTER></TD></FORM>

<FORM ACTION="committeeEvaluate.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Evaluating Applications"></CENTER></TD></FORM>

<FORM ACTION="logout.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Log Out of GPA"></CENTER></TD></FORM>

</TABLE>
</CENTER>
<img src="UNR_Wolf.gif" align=left>
</BODY>
</HTML>