<? session_start(); 
   session_destroy();
   session_start();
//*********************************************************/
//* Filename: login.php
//* Purpose: Login screen for existing users
//* Version information
//* Date: November 5, 2001
//* Copyright notice
//***********************************************************/

?>
<html>
<body>
<BODY BACKGROUND = "UNR_Seal.gif">
<center>

<img src = "UNR_Logo.gif" >
<? if($invalidLogin == 1){
echo"<p><font size=4 color=\"red\">Invalid Login</font></p>";
$invalidLogin = 0;
session_register('invalidLogin');
}
?>
<p>&nbsp;</p>
<table border=1 cellspacing=5 cellpadding=5 width="60%" height="40%">
<tr><font size=5>GPA User Login</font>
<form action="checkLogin.php" method=post>
<tr><td>Username</td>
    <td><input type="text" name="username" size=25></td>
</tr>
<tr><td>Password</td>
    <td><input type="password" name="pwd" size=25></td>
</tr>
<tr><td><input type="submit" value="Login"></td>
</tr>
</form>
</table> </center>

<p> &nbsp; </p>
<p> &nbsp; </p>
<img src = "UNR_Wolf.gif" align = left> &nbsp; &nbsp; &nbsp; <A HREF="faqPage.php"> Frequently Asked Questions </A>
</body>
</html>
