<?
session_start();

/***********************************************************
* Filename: applicant.php
* Purpose: display applicant page
* Version: 1.0
* Date: 12/8/2001
************************************************************/
if ($userType != 'a')
	header("Location: logout.php");

?>

<html>
<Title>
GPA Applicant Page
</Title>
<body>

<?
require("DB.php");

$rID = $username;

$db = new DB ("andromeda", "gradinfo");
$db -> connect();

$app = $db->getApplicant($rID); //Assume rID
$db -> disconnect();
?>
<BODY BACKGROUND = "UNR_Seal.gif">
<center>
<img src = "UNR_Logo.gif" align = center>

<br><br><br>
<p><H1> GPA Applicant Page </H1>

<br>

<center><FONT SIZE = "5"> 
<? echo $app->name->firstName; echo " "?>
<? echo $app->name->lastName; ?> 
</FONT></center>

<br>
<center><FONT SIZE = "5">
<? echo $rID ?> 
</FONT></center>

<br><br><br>
<table border = 1>
<p><FONT SIZE = "4"> <tr><td>Applicant Progress: </td></FONT>
</table>
<table border = 1>
<FONT SIZE = "3">
<tr><td>Application Status</td> 
<? echo "<td>".$app->status."</td>" ?> 
</FONT>

</table>
	

<br><br><br>
<form action="logout.php">
<FONT SIZE = "4">
<center><input type="submit" name="Logout" value="Logout"></center>
</FONT>
</form>

<img src = "UNR_Wolf.gif" align = left>
</center>
<html>
