<?
session_start();
if($userType != 'm')
	header("Location: logout.php");

/**********************************************************************************
*Name: display.php
*Purpose:1)delete a course or a project from the database
*Version information
*Date: December 2, 2001
*Copyright notice
***********************************************************************************/
require("DB.php");

$db = new DB("andromeda", "gradinfo");
$db->connect();

if($actionflag == 1){

	$myCourse = new Course( $st_course, null, $st_sem, null, null);
	$db->deleteCourse($student_id, $myCourse);
	header("Location: addCourseForm.php?event_id=$st_id");
	exit;
}else if($actionflag == 2){

	$myProject = new Project($st_projectName, $st_sponsor, $st_pSemester);
	$db->deleteProject($st_id, $myProject);
	header("Location: gradStud.php");

}else{
	//nothing
	print" NOTHING ";
}

?>
