<?
session_start();

require("DB.php");

$user = new User();

$user->name->firstName = $f;
$user->name->lastName = $l;
$user->email = $email;
$user->userType = $userType;
$user->password = $pwd;
$user->userId = $userName;

$db = new DB("andromeda","gradinfo");
$db->connect();

$db->updateUser($user);

header("Location: display.php");

?>