<? session_start();

/*********************************************************
* Filename: newUser.php
* Purpose: Display a new user screen, validates inputs by
*	   addUser.php on submit
* Version information
* Date: November 5, 2001
* Copyright notice
***********************************************************/

 session_start(); 

 if($userType != 'm'){
	header("Location: logout.php");
}
require("asstHeader.php");
//** Display appropriate messages to screen */
echo"<center>";
	if($passwordMismatch == 1){
	 echo"<font color=\"red\" size=4>Passwords Do Not Match</font>";
	 $passwordMismatch = 0;
	 session_register('passwordMismatch');
	}
	
	if($alreadyUsed == 1){
	 echo"<font color=\"red\" size=4>Username is already taken</font>";
	 $alreadyUsed = 0;
	 session_register('alreadyUsed');
	}
	
	if($blankFields == 1){
	 echo"<font color=\"red\" size=4>Please fill in all fields</font>";
	 $blankFields = 0;
	 session_register('blankFields');
	}
echo"</center>";

?>

<html>
  <body>
    
    <CENTER><table border="1"  CELLSPACING=5 CELLPADDING=5 WIDTH="60%" HEIGHT="40%">
	<tr><font size="5" COLOR="black">Add New User</font>   
	  <FORM ACTION="addUser.php" METHOD=get>
	    <tr><td>First Name</td>
	      <td><INPUT TYPE="text" NAME="f" SIZE=25 value=""></td></tr>
	    <tr><td>Last Name</td>
	      <td><INPUT TYPE="text" NAME="l" SIZE=25 value=""></td></tr>
	    <tr><td>email address</td>
	      <td><INPUT TYPE="text" NAME="email" SIZE=25 value=""></td></tr>
	    <tr><td>User Name</td>
	      <td><INPUT TYPE="text" NAME="userName"  SIZE=25 value=""></td></tr>
	    <tr><td>User Type</td>
	      <td><select name="userType">
		<option value='s'>Student
		<option value='a'>Applicant
		<option value='m'>Management Assistant
		<option value='f'>Faculty
		<option value='v'>Advisor
		<option value='c'>Graduate Commitee Member
		<option value='d'>Graduate Director
		</select></td>
	    <tr><td>Password</td>
	      <td><INPUT TYPE="password" NAME="pwd" SIZE=25 
		  MAXLENGTH=25></td></tr>
	    <tr><td>Password Again</td>
		<td><input type="password" name="pwd2" size=25 maxlength=25>
		</td>
	    </tr>
	    <tr><td><INPUT TYPE="submit" VALUE="Submit"></td>
	      <td><INPUT TYPE="reset"  NAME="reset"  VALUE="Reset"></td></tr>
	    
	  </FORM>
      </table></CENTER>
    <br>
      
  </body>
</html>
