<?
class Course{
	var $grade;
	var $semester;
	var $course;
	var $courseStatus;
	var $type; //1 = prerequisites, 2 = core, 3 = specialty

	function Course($course, $grade, $semester, $type, $status){
		$this->course = $course;
		$this->grade = $grade;
		$this->semester = $semester;
		$this->type = $type;
		$this->courseStatus = $status;
	}

}

class Name{

	var $lastName;
	var $firstName;
	var $MI;
}

class Address{
	var $city;
	var $state;
	var $country;
	var $zipcode;
	var $streetName;
	var $POBox;
}

class School{
	function School(){
	  $this->address = new Address();
	}
	var $idNumber;
	var $address;
	var $schoolName;
}

class PhoneNumber{
	var $area;
	var $suffix;
	var $prefix;
	var $countryCode;
}

class GRE{
	var $verbal;
	var $math;
	var $analytical;
}

class Project{
	var $projectName;
	var $sponsor;
	var $pSemester;
	function Project($projectName, $sponsor, $semester){
		$this->projectName= $projectName;
		$this->sponsor = $sponsor;
		$this->pSemester = $semester;
	}
}

class Applicant extends User{
	function Applicant(){
	  $this->address = new Address();
	  $this->school = new School();
	  $this->phoneNumber = new PhoneNumber();
	  $this->gre = new GRE();
	}

	var $toefl;
	var $address;
	var $school;
	var $phoneNumber;
	var $ssNumber;
	var $tGPA;
	var $gre;
	var $list_of_courses = array();
	var $dob;
	var $status;
	var $message;
	var $finalLetter;

	//dorothy added this
	var $major;
	var $dateGrad;
	var $dateAttend;
	var $programType; //moved from student to applicant
	var $typeProg;	//moved from student to applicant
	var $cGPA; //cummulative GPA from other school
	
	var $degree; //PLEASE ADD TO DATABASE
}

class Student extends Applicant{
	
	//ADDED
	function Student(){
		$this->project = new Project(null,null,null,null);
	}

	var $rNumber;
	var $ucGPA; //UNR GPA
	var $list_of_unr_course;
	var $advisor;
	var $project;
	var $comment;
	var $commentDate;
}

class User{
	function User(){
	 $this->name = new Name();
	}
	var $userId;
	var $password;
	var $email;
	var $name; 
	var $userType;
}

/*SimpleStudent Class: a brief student Info---added by Beifang Yi*/ 

class SimpleStudent{
        var $firstName;
        var $lastName;
        var $rNumber;

        function SimpleStudent($firstName, $lastName, $rNumber){
                $this->firstName = $firstName;
                $this->lastName = $lastName;
                $this->rNumber = $rNumber;
        }
}
?>
