<?php

session_start();
$user_type = 'd';
if (!($user_type=='d' || $user_type=='c'))
{
	header("Location: NoteErrorPage.php");
}
else
{
?>
<HTML>
<HEAD>
   <TITLE>GPA New Frequently Asked Question</TITLE>
</HEAD>

<BODY BGCOLOR="#FFFFFF" BACKGROUND="ZUNRBKGD.GIF">
<IMG SRC="ZUNRHDR.GIF" HEIGHT=41 WIDTH=482>
<form action="sendmail.php" method="post">

To:<input type="text" name="to"><br>
Subject:<input type="text" name="subject"><br>
<textarea name="quest" rows="10" cols="50"></textarea><br>
<textarea name="body" rows="10" cols="50"></textarea><br>
<input type="submit">
</form>
<?php
}
?>
</BODY>
</HTML>
