<?php 
session_start();
if($userType != 'm')
	header("Location: logout.php");

require ("asstHeader.php");
require ("DB.php");

//goes back to s.php.
$page=0;
session_register('page');
//print $page;

//redirect user to login page.
/*
if($userType != 'm'){
	header("Location: login.php");
}
*/

$db = new DB("andromeda", "gradinfo");
$db->connect()

?> 

<!-- comments::space &nbsp-->
<html>
<body>
<h2 align=left>UNR Computer Science--New Student Form</h2> 
<!-- <form action="<?php print $PHP_SELF;?>" method = "post"> -->
<form id ="form1" action="StudentInfo.php", method = "post">
<table border = 2> 
<tr><th width=765> NAME AND CONTACT INFORMATION</th> 
</table><br> 
<table border = 1> 
<? if($eID==1){echo"<tr><td colspan=6>
	<font color=\"red\">Fill in Name and Student ID</font>
	</td></tr>"; 
	$eID = 0;
	session_register('eID');
   } 
  if($usedSId == 1){
	  echo"<font color=\"red\">Student ID is already Taken</font>";
	}

?>
<tr><td>First Name</td><td><input type="text" name="form[firstName]" value=""></td> 
<td>Last Name</td><td><input type="text" name="form[lastName]" value=""></td> 
<td>Middle Initial</td><td><input type="text" name="form[MI]" value=""></td> 
<tr><td>Social Security Number</td><td><input type="text" name="form[ssNumber]" value=""></td> 
<td>Date of Birth</td><td><input type="text" name="form[dob]" value=""></td> 
<td><? if($usedSId == 1){  $usedSId = 0; echo"<font color=\"red\">Student ID</font>";} else echo"Student ID"; ?></td><td><input type="text" name="form[rNumber]" value=""></td> 
<tr><td colspan=6>Mailing Address</td> 
<tr><td>Street Name</td><td colspan=3><input type="text" name="form[streetName]" value=""size=55></td> 
<td>P.O. Box</td><td><input type="text" name="form[POBox]" value=""></td> 
<tr><td>City</td><td><input type="text" name="form[city]" value=""></td> 
<td>State</td><td><input type="text" name="form[state]" value=""></td> 
<td>Zip Code</td><td><input type="text" name="form[zipcode]" value=""></td> 
<tr><td>Country </td><td><input type="text" name="form[country]" value=""></td>
<td>E-Mail</td><td><input type="text" name="form[email]" value=""></td>
</table>
<table border = 1>
<tr><td>Phone Number</td><td>(</td> 
<td><input type="text" name="form[area]" value="" size=5></td><td>)</td> 
<td><input type="text" name="form[prefix]" value="" size=5></td><td><b>-</b></td>
<td><input type="text" name="form[suffix]" value="" size=7></td>
<td>Country Code</td><td><input type="text" name="form[countryCode]" value="" size=7></td>
</table><br> 
 
<table border = 2><tr><th width=765> EDUCATION</th></table> 
</table><br>
 
<table border = 1> 
<tr><td >Name of College or University</td>
<tr><td><input type="text" name="form[schoolName]" value=""size=91></td>
<tr><td><b>School Address</b><td>
<tr><td>Street Name </td>
<tr><td><input type="text" name="form[sStreet]" value=""size=91></td></table>

<table border = 1>
<tr><td>City</td><td><input type="text" name="form[sCity]" value=""></td>
	<td>State</td><td><input type="text" name="form[sState]" value=""></td>
	<td>Zip Code</td><td><input type="text" name="form[sZip]" value=""></td>
<tr><td>Country</td><td><input type="text" name="form[sCountry]" value=""></td>
	<td>ID Number</td><td><input type="text" name="form[sID]" value=""></td>
	<td>P.O. Box</td><td><input type="text" name="form[sPOBox]" value=""></td>
<tr><td>Degree Earned</td><td><input type="text" name="form[degree]" value=""></td> 
	<td>Major</td><td><input type="text" name="form[major]" value=""></td></table><br> 

<br><table border=1> 
<tr><td>Graduation / Expected Graduation Date</td><td><input type="text" name="form[dateGrad]" value=""size=31></td> 
<td>Date Attended</td><td colspan=4><input type="text" name="form[dateAttend]" value=""size=31></td></table><br> 
<table border = 1> 
<tr><td size=10>GPA</td><td>Undergraduate GPA</td><td><input type="text" name="form[cGPA]" value=""></td> 
<td>Graduate GPA</td><td><input type="text" name="form[tGPA]" value=""></td> 
<td>TOEFL</td><td><input type="text" name="form[toefl]" value=""size=17></td> 
<tr><td size=10>GRE</td><td>Analytical</td><td><input type="text" name="form[analytical]" value=""></td> 
<td>Verbal</td><td><input type="text" name="form[verbal]" value=""></td> 
<td>Quantitative</td><td><input type="text" name="form[math]" value=""size=17></td> 
</table><br> 

<table border = 2><tr><th width=765> GRADUATE PROGRAM INFORMATION</th></table> 
</table><br>
 
<table border = 1> 
<tr><td>Program type</td>
<td><select name="form[programType]">
<option>Computer Science
<option>Computer Engineering
</select></td>
<td>Degree</td>
<td><select name="form[typeProg]">
<option>M.S.
<option>Ph.D.
</select></td> 
</table><br>

<table border = 1> 
<tr><th>UNR Advisor</th><td>Advisor's Name</td><td><input type="text" name=form[advisor] value=""
	size=27></td> 

<!-- <tr><td><textarea name="form[comment]" rows=3 cols=55></textarea></td><td valign=top>Date</td> 
<td valign=top><input type="text" name="form[commentDate] value="" size=27></td> -->

</table> 
 
<input type="submit" name="Submit" value="Submit Data"> 
</form> 
</body> 
</html>
