<HTML>
<HEAD>
	<TITLE>GPA Frequently Asked Questions (FAQ)</TITLE>
</HEAD>

<BODY BACKGROUND="UNR_Seal.gif">
<center>
<IMG SRC="UNR_Logo.gif" HEIGHT=41 WIDTH=482>
<H1>GPA Frequently Asked Questions (FAQ)</H1>
<P>
<A HREF="index.php">GPA home</A><BR>
Send new questions to: <A HREF=mailto:kingj@unr.nevada.edu> gpafaq@cs.unr.edu </A> 
</P>
<?php
$QAcount = 0;
$dbh=mysql_connect (mysql, andromeda, gradinfo);

mysql_select_db(AndromedaGradInfo_DB, $dbh);

$result = mysql_query("SELECT question FROM andromeda_faq", $dbh);

while ($row = mysql_fetch_row($result))
{
	foreach ($row as $val)
	{
		$QAcount++;
		print "<A HREF=\"#Q".$QAcount."\">";
		print "$val</A><BR>";
	}
}

$result = mysql_query("SELECT * FROM andromeda_faq", $dbh);
$QAcount = 0;

while ($row = mysql_fetch_row($result))
{
	$QAcount++;
	print "<HR><P><B><A NAME =\"Q".$QAcount."\">";
	print "$row[0]<BR>";
	print "</A></B><BR>";

	print "$row[1]<BR>";
	?>
	<A HREF="#Top"> (Top) </A>
	<?php
	print "<BR><BR>";
}

mysql_close($dbh);
?>
<IMG ALIGN=LEFT SRC="UNR_Wolf.gif">
</center>
