<?
session_start();
session_unregister('aF');
session_unregister('aF1');
if($userType != 'm')
	header("Location: logout.php");

/**********************************************************************************
*Name: display.php
*Purpose: 1)Display a list of students and applicants to the management assistants staff
* 	  2)Allow staff members to update, delete, add a student or an applicant
*	  3)Allow staff members to update, delete, add a user through links in the header
*Version information
*Date: December 2, 2001
*Copyright notice
***********************************************************************************/
?>
 
<?php

require("asstHeader.php");
?>
<center>
<h2>Welcome <? echo $firstName ?></h2>
<h3>Please choose a task</h3>
<p> &nbsp; </p>
<form action="gradApp.php">
<input type="submit" value="Applicants">
</form>
<form action="gradStud.php">
<input type="submit" value="Students">
</form>
<form action="users.php">
<input type="submit" value="Users">
</form>
</center>
<img src="UNR_Wolf.gif">


