<?
/*****************************************************************
* filename: facultyClass.php
* Purpose: for director to view/evaluate students, and send
*          an FAQ, admission/rejection notice to assistant
* Version information 1.0
* Date: December 4,2001
******************************************************************/

session_start();

if($userType!='d')
 header("Location: logout.php");

?>
<HTML>
<HEAD>
<TITLE> GPA for Director </TITLE>
</HEAD>

<BODY BACKGROUND="UNR_Seal.gif">
<CENTER><img src="UNR_Logo.gif">  </CENTER>

<CENTER>
<TABLE BORDER=2 CELLSPACING=5 CELLPADDING=5 WIDTH="60%" HEIGHT="40">
<TR><STRONG><B> GPA for Director</STRONG></B>

<FORM ACTION="directorView.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Viewing Students' Info"></CENTER></TD></FORM>

<FORM ACTION="directorReport.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Reporting Students' Grades"></CENTER></TD></FORM>

<FORM ACTION="directorFAQ.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Sending an FAQ"></CENTER></TD></FORM>

<FORM ACTION="directorEvaluate.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Evaluating Applications"></CENTER></TD></FORM>

<FORM ACTION="directorLetter.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Notifying MA of Applicant's Status"></CENTER></TD></FORM>

<FORM ACTION="logout.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Logout Out of GPA"></CENTER></TD></FORM>

</TABLE>
</CENTER>

<img src="UNR_Wolf.gif align=left">
</BODY>
</HTML>
