<?
/*****************************************************************
* filename: faculty.php
* Purpose: for a faculty to view student info and report grades
*           to assistant
* Version information 1.0
* Date: December 4,2001
******************************************************************/

session_start();

if(($userType!='f')&&($userType!='v'))
 header("Location: logout.php");

?>


<HTML>
<HEAD>
<TITLE> GPA for Faculty </TITLE>
</HEAD>


<BODY BACKGROUND="UNR_Seal.gif">
<CENTER><img src="UNR_Logo.gif">  </CENTER>

<CENTER>
<TABLE BORDER=2 CELLSPACING=5 CELLPADDING=5 WIDTH="60%" HEIGHT="40">
<TR> <STRONG><B>GPA for Faculty</STRONG></B>
<FORM ACTION="facultyView.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Viewing Students' Info"></CENTER></TD></FORM>

<FORM ACTION="facultyReport.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Reporting Students' Grades"></CENTER></TD>
</form>
<FORM ACTION="logout.php" METHOD=POST>
<TR><TD><CENTER><INPUT TYPE="SUBMIT" VALUE="Log Out of GPA"></CENTER></TD>
</FORM>
</TABLE>
</CENTER>
<img src="UNR_Wolf.gif" align=left>
</BODY>
</HTML>
